aboutsummaryrefslogtreecommitdiff
path: root/src/patch/patch.hh
diff options
context:
space:
mode:
Diffstat (limited to 'src/patch/patch.hh')
-rw-r--r--src/patch/patch.hh44
1 files changed, 22 insertions, 22 deletions
diff --git a/src/patch/patch.hh b/src/patch/patch.hh
index 616c875..0b7d8fe 100644
--- a/src/patch/patch.hh
+++ b/src/patch/patch.hh
@@ -57,16 +57,16 @@
// overlaps another patch. Such an object knows how to get ghost
// zone gridfn data from the other patch. More accurately, it gets
// the data by asking (calling) the appropriate one of the other
-// patch's patch_frontier objects.
+// patch's patch_interp objects.
// Every patch has (points to) 4 ghost_zone objects, one for each of
// the patch's sides.
//
// A patch_frontier object represents the part of a patch *inside*
// its nominal grid from which data is interpolated to compute gridfns
// in another patch's ghost zone. A patch_frontier object stores
// information about the interpolator (which interpolator to use, any
// options for it) and any cached data for the interpolator. Every
// patch has (points to) between 0 and 4 patch_frontier objects,
// one for each of the patch's sides where there's an adjacent patch
// and thus from which interpolation is done.
//
@@ -75,14 +75,14 @@
// this (omitting the patch_edge objects for simplicity):
//
// +-----+ +-----+
-// | | <--> p.interpatch_ghost_zone --> q.patch_frontier <--> | |
+// | | <--> p.interpatch_ghost_zone --> q.patch_interp <--> | |
// | p | | q |
-// | | <--> p.patch_frontier <-- q.interpatch_ghost_zone <--> | |
+// | | <--> p.patch_interp <-- q.interpatch_ghost_zone <--> | |
// +-----+ +-----+
//
// Because of the mutual pointers, we can't easily construct (say)
// p's interpatch_ghost_zone until after q itself has been constructed,
// and vice versa. Moreover, the patch_frontier:: constructor
// needs the adjacent-side ghost_zone objects to already exist,
// and it needs to know the iperp range of the frontier, which can
// only be computed from the adjacent-patch interpatch_ghost_zone
@@ -101,9 +101,9 @@
// * The patch_system constructor calls the functions
// interpatch_ghost_zone::finish_setup()
// to finish setting up the interpatch_ghost_zone objects, construct
// the patch_frontier objects and interlink them from their patches,
// and finish linking the interpatch_ghost_zone objects to the
-// patch_frontier objects.
+// patch_interp objects.
//
//*****************************************************************************
@@ -129,7 +129,7 @@ class patch_edge;
class ghost_zone;
class symmetry_ghost_zone;
class interpatch_ghost_zone;
-class patch_frontier;
+class patch_interp;
class patch_system;
//
@@ -351,7 +351,7 @@ private:
void set_ghost_zone(const patch_edge& edge, ghost_zone* gzp);
// this function is used only by
- // interpatch_ghost_zone::setup_other_patch_frontier():
+ // interpatch_ghost_zone::setup_other_patch_interp():
// it assert() that the patch frontier pointer on the specified edge
// is NULL (i.e. that we haven't already setup this patch frontier),
// then assigns a new value to it
@@ -361,17 +361,17 @@ private:
//
// KLUDGE:
// ... this function should really be private, and
- // interpatch_ghost_zone::setup_other_patch_frontier():
+ // interpatch_ghost_zone::setup_other_patch_interp():
// be declared a friend of this class, but .cc files need
// to #include this header file ("patch.hh") before
// "ghost_zone.hh" to get inline functions properly inlined,
// so there's no clean way to make
- // interpatch_ghost_zone::setup_other_patch_frontier():
+ // interpatch_ghost_zone::setup_other_patch_interp():
// a friend here ==> we just make it public for now :( :(
//
public:
- void set_patch_frontier(const patch_edge& edge,
- const patch_frontier* pfp)
+ void set_patch_interp(const patch_edge& edge,
+ const patch_interp* pfp)
const;
@@ -438,15 +438,15 @@ private:
// frontiers (NULL pointers if no frontier for this ghost zone)
// ... pointers are set to NULL by ctor,
// reset for those cases where there *is* a frontier by
// set_patch_frontier(), which is called by the *other* patch's
// interpatch_ghost_zone::setup_other_patch_frontier()
// ... contrary to appearance, "mutable" here refers to the pointers,
// not to the patch_frontier objects to which they point!
//
- mutable const patch_frontier* min_rho_patch_frontier_;
- mutable const patch_frontier* max_rho_patch_frontier_;
- mutable const patch_frontier* min_sigma_patch_frontier_;
- mutable const patch_frontier* max_sigma_patch_frontier_;
+ mutable const patch_interp* min_rho_patch_interp_;
+ mutable const patch_interp* max_rho_patch_interp_;
+ mutable const patch_interp* min_sigma_patch_interp_;
+ mutable const patch_interp* max_sigma_patch_interp_;
};
//*****************************************************************************
@@ -57,16 +57,16 @@
// the patch's sides.
//
-// A patch_frontier object represents the part of a patch *inside*
+// A patch_interp object represents the part of a patch *inside*
// its nominal grid from which data is interpolated to compute gridfns
@@ -57,16 +57,16 @@
// its nominal grid from which data is interpolated to compute gridfns
-// in another patch's ghost zone. A patch_frontier object stores
+// in another patch's ghost zone. A patch_interp object stores
// information about the interpolator (which interpolator to use, any
// options for it) and any cached data for the interpolator. Every
@@ -57,16 +57,16 @@
// information about the interpolator (which interpolator to use, any
// options for it) and any cached data for the interpolator. Every
-// patch has (points to) between 0 and 4 patch_frontier objects,
+// patch has (points to) between 0 and 4 patch_interp objects,
// one for each of the patch's sides where there's an adjacent patch
// and thus from which interpolation is done.
@@ -75,14 +75,14 @@
// Because of the mutual pointers, we can't easily construct (say)
// p's interpatch_ghost_zone until after q itself has been constructed,
-// and vice versa. Moreover, the patch_frontier:: constructor
+// and vice versa. Moreover, the patch_interp:: constructor
// needs the adjacent-side ghost_zone objects to already exist,
// and it needs to know the iperp range of the frontier, which can
@@ -101,9 +101,9 @@
// interpatch_ghost_zone::finish_setup()
// to finish setting up the interpatch_ghost_zone objects, construct
-// the patch_frontier objects and interlink them from their patches,
+// the patch_interp objects and interlink them from their patches,
// and finish linking the interpatch_ghost_zone objects to the
@@ -438,15 +438,15 @@ private:
// ... pointers are set to NULL by ctor,
// reset for those cases where there *is* a frontier by
- // set_patch_frontier(), which is called by the *other* patch's
- // interpatch_ghost_zone::setup_other_patch_frontier()
+ // set_patch_interp(), which is called by the *other* patch's
+ // interpatch_ghost_zone::setup_other_patch_interp()
// ... contrary to appearance, "mutable" here refers to the pointers,
@@ -438,15 +438,15 @@ private:
// ... contrary to appearance, "mutable" here refers to the pointers,
- // not to the patch_frontier objects to which they point!
+ // not to the patch_interp objects to which they point!
//